/*
 * @(#) eat.c  Eats the first X lines from stdin (default 1)
 *
 * Handy for use in pipelies where you want to process the output lines of
 * another program, but the header lines get in the way. Programs like ps,
 * dpkg, and sar are all good examples.  Unfortuantely, not all programs are as
 * kind as ps in supplying flags such as --no-headers. Eat exists to fill this
 * gap.
 *
 * compile with: gcc eat.c -o eat
 *
 * This program was written by Mark Whitley <markw@enol.com>
 * This program is in the public domain.
 */

#include <stdio.h>

#define VERSION "0.1"
#define NEWLINE '\n'
/* Value of newline can be changed as needed (i.e. \r for Mac) */

int main(int argc, char** argv)
{
	/* default is to just eat one line
	 * (typical ammount of header lines produced by many programs)
	 */
	int eatme = 1;
	char ch;

	if (argc > 1) {
		/* check for switches */
		if (argv[1][0] == '-') {
			/* -v = print version */
			if (argv[1][1] == 'v') {
				printf("%s: ver %s\n", argv[0], VERSION);
				exit(0);
			}
			/* -h or -? = print help message */
			/* if (argv[1][1] == 'h' || argv[1][1] == '?') { */
			else {
				printf("Usage: %s [num]\n", argv[0]);
				printf("Removes the first num lines from stdin ");
				printf("and writes the remainder to stdout\n");
				printf("\tnum specifies number of lines to eat (default 1)\n");
				exit(0);
			}
		} else { /* no flags */
			/* user can specify how many lines to eat as cmd-line arg */
			eatme = atoi(argv[1]);
			/* FIXME error check this arg better with isdigit()? */
		}
	}

	while ((ch = fgetc(stdin)) != EOF) {
		if (eatme > 0) {
			if (ch == NEWLINE)
				eatme--;
			continue;
		} else { 
			printf("%c", ch);
		}
	}

	return 0;
}
